from petisco.domain.value_objects.user_id import UserId

DEFAULT_ORGANIZATION = "alice"
DEFAULT_SERVICE = "petisco"
DEFAULT_EXCHANGE_NAME = f"{DEFAULT_ORGANIZATION}.{DEFAULT_SERVICE}"
DEFAULT_USER_ID = UserId("9f74b5c0-2196-4a27-a03f-cb92d66e2bbd")
DEFAULT_MAX_RETRIES = 5
DEFAULT_VERBOSE = True
